@@ -853,6 +853,14 @@ PLAN_TASK_SCHEMA = '''{
                     "maxItems": 7,
                     "minItems": 0,
                     "type": "array"
+                },
+                "trip_start_time_strategy": {
+                    "default": "EARLIEST_FINISH",
+                    "enum": [
+                        "EARLIEST_FINISH",
+                        "LOWEST_COST"
+                    ],
+                    "type": "string"
                 }
             },
             "type": "object"
